@@ -1,9 +1,9 @@
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 // SPDX-FileCopyrightText: 2020 Harald Sitter <sitter@kde.org>
 
-#include <QCoreApplication>
-#include <KPluginFactory>
 #include <KDEDModule>
+#include <KPluginFactory>
+#include <QCoreApplication>
 
 #include "dbusobjectmanagerserver.h"
 #include "device.h"
@@ -18,25 +18,21 @@ public:
         : KDEDModule(parent)
     {
         Q_UNUSED(args);
-        connect(&m_monitor, &SMARTMonitor::deviceAdded,
-                this, [this](Device *device) {
+        connect(&m_monitor, &SMARTMonitor::deviceAdded, this, [this](Device *device) {
             dbusDeviceServer.serve(device);
         });
-        connect(&m_monitor, &SMARTMonitor::deviceRemoved,
-                &dbusDeviceServer, [this](Device *device) {
+        connect(&m_monitor, &SMARTMonitor::deviceRemoved, &dbusDeviceServer, [this](Device *device) {
             dbusDeviceServer.unserve(device);
         });
         m_monitor.start();
     }
 
 private:
-    SMARTMonitor m_monitor { new SMARTCtl };
-    SMARTNotifier m_notifier { &m_monitor };
+    SMARTMonitor m_monitor{new SMARTCtl};
+    SMARTNotifier m_notifier{&m_monitor};
     KDBusObjectManagerServer dbusDeviceServer;
 };
 
-K_PLUGIN_FACTORY_WITH_JSON(SMARTModuleFactory,
-                           "smart.json",
-                           registerPlugin<SMARTModule>();)
+K_PLUGIN_FACTORY_WITH_JSON(SMARTModuleFactory, "smart.json", registerPlugin<SMARTModule>();)
 
 #include "main.moc"
